@@ -4,114 +4,75 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.655';
+our $VERSION = '1.700';
 
 use Exporter qw( import );
 
 our @EXPORT_OK = qw(
-        ROW COL
-        HIDE_CURSOR SHOW_CURSOR WIDTH_CURSOR
-        MAX_ROW_MOUSE_1003 MAX_COL_MOUSE_1003
-        GET_CURSOR_POSITION
-        SET_ANY_EVENT_MOUSE_1003 SET_EXT_MODE_MOUSE_1005 SET_SGR_EXT_MODE_MOUSE_1006
-        UNSET_ANY_EVENT_MOUSE_1003 UNSET_EXT_MODE_MOUSE_1005 UNSET_SGR_EXT_MODE_MOUSE_1006
-        CLEAR_SCREEN CLEAR_TO_END_OF_SCREEN CLEAR_TO_END_OF_LINE
-        RESET REVERSE UNDERLINE BOLD_UNDERLINE BEEP
-        UP DOWN RIGHT LEFT
+        SET_ANY_EVENT_MOUSE_1003 SET_SGR_EXT_MODE_MOUSE_1006
+        UNSET_ANY_EVENT_MOUSE_1003 UNSET_SGR_EXT_MODE_MOUSE_1006
+
+        MOUSE_WHEELED LEFTMOST_BUTTON_PRESSED RIGHTMOST_BUTTON_PRESSED FROM_LEFT_2ND_BUTTON_PRESSED
+        VK_CODE_PAGE_UP VK_CODE_PAGE_DOWN VK_CODE_END VK_CODE_HOME VK_CODE_LEFT
+        VK_CODE_UP VK_CODE_RIGHT VK_CODE_DOWN VK_CODE_INSERT VK_CODE_DELETE
+
         NEXT_get_key
         CONTROL_SPACE LINE_FEED CARRIAGE_RETURN CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H
         CONTROL_I CONTROL_K CONTROL_Q CONTROL_U CONTROL_X
         KEY_BTAB KEY_TAB KEY_ESC KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
-        VK_CODE_PAGE_UP VK_CODE_PAGE_DOWN VK_CODE_END VK_CODE_HOME VK_CODE_LEFT VK_CODE_UP VK_CODE_RIGHT VK_CODE_DOWN
-        VK_CODE_INSERT VK_CODE_DELETE
-        MOUSE_WHEELED
-        LEFTMOST_BUTTON_PRESSED RIGHTMOST_BUTTON_PRESSED FROM_LEFT_2ND_BUTTON_PRESSED
+
+        WIDTH_CURSOR
+
+        TERM_READKEY
 );
 
 our %EXPORT_TAGS = (
-    choose => [ qw(
-        ROW COL
-        MAX_ROW_MOUSE_1003 MAX_COL_MOUSE_1003
-        NEXT_get_key
-        CONTROL_SPACE CONTROL_A CONTROL_B CONTROL_C CONTROL_E CONTROL_F CONTROL_H KEY_BTAB CONTROL_I CONTROL_Q KEY_TAB
-        LINE_FEED CARRIAGE_RETURN KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
-        VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
+    linux => [ qw(
+        SET_ANY_EVENT_MOUSE_1003 SET_SGR_EXT_MODE_MOUSE_1006
+        UNSET_ANY_EVENT_MOUSE_1003 UNSET_SGR_EXT_MODE_MOUSE_1006
     ) ],
-    form => [ qw(
-        NEXT_get_key
-        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H KEY_BTAB KEY_TAB CONTROL_K CONTROL_U CONTROL_X
-        LINE_FEED CARRIAGE_RETURN KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_BSPACE KEY_ESC
-        VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
+    win32 => [ qw(
+        MOUSE_WHEELED LEFTMOST_BUTTON_PRESSED RIGHTMOST_BUTTON_PRESSED FROM_LEFT_2ND_BUTTON_PRESSED
+        VK_CODE_PAGE_UP VK_CODE_PAGE_DOWN VK_CODE_END VK_CODE_HOME VK_CODE_LEFT
+        VK_CODE_UP VK_CODE_RIGHT VK_CODE_DOWN VK_CODE_INSERT VK_CODE_DELETE
     ) ],
-    screen => [ qw(
-        CLEAR_SCREEN CLEAR_TO_END_OF_SCREEN CLEAR_TO_END_OF_LINE UP DOWN RIGHT LEFT
-        RESET REVERSE UNDERLINE BOLD_UNDERLINE HIDE_CURSOR SHOW_CURSOR BEEP WIDTH_CURSOR
-    ) ],
-    linux  => [ qw(
-        GET_CURSOR_POSITION
-        SET_ANY_EVENT_MOUSE_1003 SET_EXT_MODE_MOUSE_1005 SET_SGR_EXT_MODE_MOUSE_1006
-        UNSET_ANY_EVENT_MOUSE_1003 UNSET_EXT_MODE_MOUSE_1005 UNSET_SGR_EXT_MODE_MOUSE_1006
+    keys => [ qw(
         NEXT_get_key
-        KEY_BTAB KEY_ESC
+        CONTROL_SPACE LINE_FEED CARRIAGE_RETURN CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H
+        CONTROL_I CONTROL_K CONTROL_Q CONTROL_U CONTROL_X
+        KEY_BTAB KEY_TAB KEY_ESC KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
-    ) ],
-    win32  => [ qw(
-        NEXT_get_key
-        CONTROL_SPACE
-        VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
-        VK_CODE_PAGE_UP VK_CODE_PAGE_DOWN VK_CODE_END VK_CODE_HOME VK_CODE_LEFT VK_CODE_UP VK_CODE_RIGHT VK_CODE_DOWN
-        VK_CODE_INSERT VK_CODE_DELETE
-        MOUSE_WHEELED
-        LEFTMOST_BUTTON_PRESSED RIGHTMOST_BUTTON_PRESSED FROM_LEFT_2ND_BUTTON_PRESSED
     ) ]
 );
 
+use constant TERM_READKEY => eval { require Term::ReadKey; 1 };
+
+use constant WIDTH_CURSOR => 1;
 
 use constant {
-    ROW => 0,
-    COL => 1,
-};
-
-use constant {
-
-    UP    => "\e[A",
-    DOWN  => "\e[B",
-    RIGHT => "\e[C",
-    LEFT  => "\e[D",
-
-    BEEP                   => "\a",
-    CLEAR_SCREEN           => "\e[H\e[J",
-    CLEAR_TO_END_OF_SCREEN => "\e[0J",
-    CLEAR_TO_END_OF_LINE   => "\e[K",
-    RESET                  => "\e[0m",
-    UNDERLINE              => "\e[4m",
-    BOLD_UNDERLINE         => "\e[1m\e[4m",
-    REVERSE                => "\e[7m",
-
-    HIDE_CURSOR  => "\e[?25l",
-    SHOW_CURSOR  => "\e[?25h",
-    WIDTH_CURSOR => 1,
-};
-
-use constant {
-    GET_CURSOR_POSITION => "\e[6n",
-
     SET_ANY_EVENT_MOUSE_1003      => "\e[?1003h",
-    SET_EXT_MODE_MOUSE_1005       => "\e[?1005h",
     SET_SGR_EXT_MODE_MOUSE_1006   => "\e[?1006h",
     UNSET_ANY_EVENT_MOUSE_1003    => "\e[?1003l",
-    UNSET_EXT_MODE_MOUSE_1005     => "\e[?1005l",
     UNSET_SGR_EXT_MODE_MOUSE_1006 => "\e[?1006l",
+};
 
-    MAX_ROW_MOUSE_1003 => 223,
-    MAX_COL_MOUSE_1003 => 223,
-
+use constant {
     MOUSE_WHEELED                => 0x0004,
-
     LEFTMOST_BUTTON_PRESSED      => 0x0001,
     RIGHTMOST_BUTTON_PRESSED     => 0x0002,
     FROM_LEFT_2ND_BUTTON_PRESSED => 0x0004,
+
+    VK_CODE_PAGE_UP   => 33,
+    VK_CODE_PAGE_DOWN => 34,
+    VK_CODE_END       => 35,
+    VK_CODE_HOME      => 36,
+    VK_CODE_LEFT      => 37,
+    VK_CODE_UP        => 38,
+    VK_CODE_RIGHT     => 39,
+    VK_CODE_DOWN      => 40,
+    VK_CODE_INSERT    => 45,
+    VK_CODE_DELETE    => 46,
 };
 
 use constant {
@@ -154,17 +115,6 @@ use constant {
     VK_DOWN       => 340,
     VK_INSERT     => 345,
     VK_DELETE     => 346,
-
-    VK_CODE_PAGE_UP   => 33,
-    VK_CODE_PAGE_DOWN => 34,
-    VK_CODE_END       => 35,
-    VK_CODE_HOME      => 36,
-    VK_CODE_LEFT      => 37,
-    VK_CODE_UP        => 38,
-    VK_CODE_RIGHT     => 39,
-    VK_CODE_DOWN      => 40,
-    VK_CODE_INSERT    => 45,
-    VK_CODE_DELETE    => 46,
 };
 
 
