@@ -2,18 +2,24 @@ package Term::Choose::Screen;
 
 use warnings;
 use strict;
-use 5.10.1;
+use 5.008003;
 
-our $VERSION = '1.778_04';
+our $VERSION = '1.700';
 
 use Exporter qw( import );
 
-our @EXPORT_OK = qw(
-    down up left right clear_screen clear_to_end_of_screen clear_to_end_of_line reverse_video bold underline
-    bold_underline normal show_cursor hide_cursor bell get_term_size
-);
+our @EXPORT_OK = qw( down up left right clear_screen clear_to_end_of_screen clear_to_end_of_line
+                     reverse_video bold underline bold_underline normal show_cursor hide_cursor bell
+                     get_term_size
+                );
 
-our %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
+our %EXPORT_TAGS = (
+    all => [ qw( down up left right clear_screen clear_to_end_of_screen clear_to_end_of_line
+                 reverse_video bold underline bold_underline normal show_cursor hide_cursor bell
+                 get_term_size
+            )
+        ]
+);
 
 use Term::Choose::Constants qw( WIDTH_CURSOR TERM_READKEY );
 
@@ -28,7 +34,7 @@ my (
 
 
 BEGIN {
-    if ( $^O eq 'MSWin32' || $ENV{TC_ANSI_ESCAPES} || ! qx(tput cuu 2>/dev/null) ) {
+    if ( $^O eq 'MSWin32' || $ENV{TC_ANSI_ESCAPES} || system( "tput -V &> /dev/null" ) ) {
         @up    = ( "\e[", "A" );
         @down  = ( "\e[", "B" );
         @right = ( "\e[", "C" );
@@ -68,6 +74,7 @@ BEGIN {
         $show_cursor = qx(tput cnorm);
         $hide_cursor = qx(tput civis);
     }
+
 }
 
 
@@ -93,19 +100,13 @@ sub bell { return $bell }
 
 
 sub get_term_size {
-    my ( $width, $height, $error );
+    my ( $width, $height ) = ( 0, 0 );
     if ( TERM_READKEY ) {
         ( $width, $height ) = ( Term::ReadKey::GetTerminalSize() )[ 0, 1 ];
-        if ( ! $width || ! $height ) {
-            $error = "get_term_size - Term::ReadKey::GetTerminalSize:";
-        }
     }
     elsif( $^O eq 'MSWin32' ) {
         require Win32::Console;
         ( $width, $height ) = Win32::Console->new()->Size();
-        if ( ! $width || ! $height ) {
-            $error = "get_term_size - Win32::Console Size:";
-        }
     }
     else {
         my $size = qx(stty size);
@@ -113,14 +114,6 @@ sub get_term_size {
             $width  = $2;
             $height = $1;
         }
-        if ( ! $width || ! $height ) {
-            $error = "get_term_size - stty size:";
-        }
-    }
-    if ( $error ) {
-        $error .=  " No term width!" if ! $width;
-        $error .=  " No term height!" if ! $height;
-        die $error;
     }
     return $width - WIDTH_CURSOR, $height;
 }
